@@ -27,9 +27,9 @@ def get_client_holding_data(clients, quarter_id):
 
     client_holdings = pd.DataFrame()
     if clients.shape[0] % 10 == 0:
-        num_reqs = clients.shape[0] / 10
+        num_reqs = int(clients.shape[0] / 10)
     else:
-        num_reqs = (clients.shape[0] // 10) + 1
+        num_reqs = int((clients.shape[0] // 10) + 1)
     for x in range(num_reqs):
         these_ids = list(clients.iloc[x*10:(x+1)*10,:]["filer_id"])
         api_input = '{"command":"holdings","quarter_ids":[%d], "filer_ids":%s, "columns":[2,4,5,6,7,10,12,16,25]}' % (quarter_id, these_ids)
